@@ -7,7 +7,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION    = '0.50';
+our $VERSION    = '0.501';
 our $XS_VERSION = $VERSION;
 
 use Carp;
@@ -871,31 +871,31 @@ EFL::Elementary - Perl bindings for Elementary from the Enlightenment Foundation
 
 =head1 VERSION
 
-version 0.500
+version 0.501
 
 =head1 SYNOPSIS
 
-use EFL::Elementary qw(:all);
-use EFL::Evas qw(:all);
-
-elm_init();
-my $win = elm_win_add(undef, "main", ELM_WIN_BASIC);
-
-elm_win_title_set($win, "my first window");
-
-evas_object_smart_callback_add($win, "delete,request", sub { elm_exit() }, undef);
-
-my $bg = elm_bg_add($win);
-evas_object_size_hint_weight_set($bg, 1.0, 1.0);
-elm_win_resize_object_add($win, $bg);
-evas_object_show($bg);
-
-evas_object_resize($win, 100, 100);
-evas_object_show($win);
-
-elm_run();
-
-elm_exit();
+    use EFL::Elementary qw(:all);
+    use EFL::Evas qw(:all);
+    
+    elm_init();
+    my $win = elm_win_add(undef, "main", ELM_WIN_BASIC);
+    
+    elm_win_title_set($win, "my first window");
+    
+    evas_object_smart_callback_add($win, "delete,request", sub { elm_exit() }, undef);
+    
+    my $bg = elm_bg_add($win);
+    evas_object_size_hint_weight_set($bg, 1.0, 1.0);
+    elm_win_resize_object_add($win, $bg);
+    evas_object_show($bg);
+    
+    evas_object_resize($win, 100, 100);
+    evas_object_show($win);
+    
+    elm_run();
+    
+    elm_exit();
 
 =head1 DESCRIPTION
 
@@ -911,7 +911,7 @@ may change in future releases.
 
 =head1 EXPORTED API/CONSTANTS
 
-Note: this list is autogenerated from F<misc/supported-api.pl>.
+    Note: this list is autogenerated from F<misc/supported-api.pl>.
     
     ELM_FLIP_ROTATE_X_CENTER_AXIS
     ELM_FLIP_ROTATE_Y_CENTER_AXIS
@@ -1434,6 +1434,26 @@ Note: this list is autogenerated from F<misc/supported-api.pl>.
     elm_win_sticky_set
     elm_win_title_set
 
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc EFL::Elementary
+
+You can also look for information at:
+
+=over
+
+=item * RT: CPAN's request tracker: L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=EFL>
+
+=item * AnnoCPAN: Annotated CPAN documentation: L<http://annocpan.org/dist/EFL>
+
+=item * CPAN Ratings: L<http://cpanratings.perl.org/d/EFL>
+
+=item * Search CPAN: L<http://search.cpan.org/dist/EFL>
+
+=back
+
 =head1 SEE ALSO
 
 =over
