@@ -7,8 +7,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.50';
-$VERSION = eval $VERSION;    ## no critic
+our $VERSION = '0.501';
 our $XS_VERSION = $VERSION;
 
 use Carp;
@@ -669,7 +668,7 @@ EFL::Evas - Perl bindings for Evas from the Enlightenment Foundation Libraries
 
 =head1 VERSION
 
-version 0.500
+version 0.501
 
 =head1 SYNOPSIS
 
@@ -692,7 +691,7 @@ may change in future releases.
 
 =head1 EXPORTED API/CONSTANTS
 
-Note: this list is autogenerated from F<misc/supported-api.pl>.
+    Note: this list is autogenerated from F<misc/supported-api.pl>.
     
     EVAS_ALLOC_ERROR_FATAL
     EVAS_ALLOC_ERROR_NONE
@@ -1248,6 +1247,26 @@ Note: this list is autogenerated from F<misc/supported-api.pl>.
     evas_transform_shear
     evas_transform_translate
 
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc EFL::Evas
+
+You can also look for information at:
+
+=over
+
+=item * RT: CPAN's request tracker: L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=EFL>
+
+=item * AnnoCPAN: Annotated CPAN documentation: L<http://annocpan.org/dist/EFL>
+
+=item * CPAN Ratings: L<http://cpanratings.perl.org/d/EFL>
+
+=item * Search CPAN: L<http://search.cpan.org/dist/EFL>
+
+=back
+
 =head1 SEE ALSO
 
 =over
